@@ -12,11 +12,9 @@ use Sys::Hostname;
 #use Regexp::Common qw (URI);
 
 require Exporter;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter);
 
-$VERSION = '0.12';
-
 #############################################
 sub Examine {
   my ($decoded,$dataref)=@_;
