@@ -11,11 +11,9 @@ use VOMS::Lite::RSAKey;
 use VOMS::Lite::CertKeyHelper;
 
 require Exporter;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw(@ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @ISA = qw(Exporter);
 
-$VERSION = '0.12';
-
 sub Examine {
   my ($decoded,$dataref)=@_;
   my %Values=%$dataref;
